Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PublicKey ¶
PublicKey is an alias for ssh.PublicKey to avoid requiring callers to import golang.org/x/crypto/ssh.
func ParseAuthorizedKeys ¶
ParseAuthorizedKeys parses an OpenSSH authorized_keys file and returns the parsed public keys. Lines that are empty or start with '#' are skipped.
type Signer ¶
Signer is an alias for ssh.Signer to avoid requiring callers to import golang.org/x/crypto/ssh.
func GenerateAndSaveHostKey ¶
GenerateAndSaveHostKey generates an SSH host key of the specified type and saves it to path with 0600 permissions atomically, then returns a signer for the key.
func ParseHostKeyFile ¶
ParseHostKeyFile reads a PEM-encoded private key and returns an SSH signer.
Click to show internal directories.
Click to hide internal directories.